@@ -28,23 +28,19 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 #include <pthread.h>
 #include <stdint.h>
 #include <libHX.h>
-#if LIBHX_VERSION < 20040905
+#if LIBHX_VERSION < 20040908
 #    error --------------------------------------------
-#    error You need a newer version of libHX (20040905)
+#    error You need a newer version of libHX (20040908)
 #    error --------------------------------------------
 #endif
 
 #define RECEIVE_FULL(fd, ptr, sz) \
     (recv((fd), (ptr), (sz), MSG_WAITALL) == (sz))
 
-struct Optmap_t {
-    int _running;
-    char *ovdev, *fbdev, *ofmt;
-    int nocreat, syslog, verbose;
-    long bsize, user_id;
-
-    char *infod_port;
-    int infod_start;
+struct GOptmap_t {
+    int syslog, verbose;
+    long user_id;
+    const char *infod_port;
 };
 
 struct Statmap_t {
@@ -54,6 +50,7 @@ struct Statmap_t {
 
 struct tty {
     uint32_t dev;
+    uid_t uid;
     int fd, status;
     size_t in, out;
     char *file;
@@ -64,9 +61,11 @@ enum {
     IFP_ACTIVATE,
     IFP_DEACTIVATE,
     IFP_DEACTIVSES, // deactivate logging until tty is closed
+    IFP_GETINFO_T,
     IFP_GETINFO,
     IFP_REMOVE,
     IFP_FLUSH,
+    IFP_ZERO,
 
     NF_NEWLINE = 1 << 0,
 };
@@ -82,7 +81,7 @@ extern int rplctl_main(int, const char **);
 extern pthread_mutex_t Ttys_lock;
 extern struct HXbtree *Ttys;
 extern struct Statmap_t Stats;
-extern struct Optmap_t Opt;
+extern struct GOptmap_t GOpt;
 
 extern char *G_devname_nm(uint32_t, char *, size_t);
 extern char *G_devname_fs(uint32_t, char *, size_t);
