@@ -86,13 +86,13 @@ inline static void mv_user(void *, size_t);
 inline static void my_swab(void *, size_t);
 
 // Variables
-static DECLARE_WAIT_QUEUE_HEAD(GV_inq);
-static DECLARE_MUTEX(GV_open_lock);
-static DECLARE_MUTEX(GV_buf_lock);
-static char *GV_buffer = NULL, *GV_bufr = NULL, *GV_bufw = NULL;
-static size_t GI_bufsize = 16384; // Each tty has a buffer of 4096
-static int GI_minor = MISC_DYNAMIC_MINOR;
-static struct file_operations GI_fops = {
+static DECLARE_WAIT_QUEUE_HEAD(Inqueue);
+static DECLARE_MUTEX(Open_lock);
+static DECLARE_MUTEX(Buffer_lock);
+static char *Buffer = NULL, *BufRP = NULL, *BufWP = NULL;
+static size_t Bufsize = 16384; // Each tty has a buffer of 4096
+static int Minor_nr = MISC_DYNAMIC_MINOR;
+static struct file_operations Fops = {
     open:    uif_open,
     read:    uif_read,
     llseek:  uif_llseek,
@@ -101,19 +101,19 @@ static struct file_operations GI_fops = {
     release: uif_close,
     owner:   THIS_MODULE,
 };
-static struct miscdevice GI_misc =
- {minor: MISC_DYNAMIC_MINOR, name: "rpl", fops: &GI_fops};
+static struct miscdevice Misc_info =
+ {minor: MISC_DYNAMIC_MINOR, name: "rpl", fops: &Fops};
 
 // Module info
 int __init init_module(void);
 void __exit cleanup_module(void);
 MODULE_DESCRIPTION("ttyrpld Kernel interface");
 MODULE_AUTHOR("Jan Engelhardt <jengelh [at] linux01 gwdg de>");
-MODULE_LICENSE("GPL");
-MODULE_PARM(GI_bufsize, "i");
-MODULE_PARM_DESC(GI_bufsize, "Buffer size (default 16K)");
-MODULE_PARM(GI_minor, "i");
-MODULE_PARM_DESC(GI_minor, "Minor number to use (default: DYNAMIC)");
+MODULE_LICENSE("GPL v2");
+MODULE_PARM(Bufsize, "i");
+MODULE_PARM_DESC(Bufsize, "Buffer size (default 16K)");
+MODULE_PARM(Minor_nr, "i");
+MODULE_PARM_DESC(Minor_nr, "Minor number to use (default: DYNAMIC)");
 #ifdef KERNEL_2_4
 EXPORT_NO_SYMBOLS;
 #endif
@@ -121,17 +121,17 @@ EXPORT_NO_SYMBOLS;
 //-----------------------------------------------------------------------------
 int __init init_module(void) {
     int eax;
-    GI_misc.minor = GI_minor;
-    if((eax = misc_register(&GI_misc)) != 0) {
+    Misc_info.minor = Minor_nr;
+    if((eax = misc_register(&Misc_info)) != 0) {
         cleanup_module();
         return eax;
     }
-    printk("RPL device registered at minor %d\n", GI_misc.minor);
+    printk("RPL device registered at minor %d\n", Misc_info.minor);
     return 0;
 }
 
 void __exit cleanup_module(void) {
-    misc_deregister(&GI_misc);
+    misc_deregister(&Misc_info);
     return;
 }
 
@@ -203,7 +203,7 @@ static int krn_close(struct tty_struct *tty) {
 
 //-----------------------------------------------------------------------------
 static int uif_open(struct inode *inode, struct file *filp) {
-    // This one is called when the driver /dev/misc/rpl has been opened.
+    // This one is called when the device node has been opened.
     if(inode != NULL) {
         inode->i_mtime = CURRENT_TIME;
         inode->i_mode &= ~(S_IWUGO | S_IXUGO);
@@ -215,14 +215,14 @@ static int uif_open(struct inode *inode, struct file *filp) {
 
     /* The RPL device can only be opened once, since otherwise, different
     packets could go to different readers. */
-    if(down_trylock(&GV_open_lock) != 0) { return -EBUSY; }
+    if(down_trylock(&Open_lock) != 0) { return -EBUSY; }
 
-    GV_buffer = __vmalloc(GI_bufsize, GFP_USER | __GFP_HIGHMEM, PAGE_KERNEL);
-    if(GV_buffer == NULL) {
-        up(&GV_open_lock);
+    Buffer = __vmalloc(Bufsize, GFP_USER | __GFP_HIGHMEM, PAGE_KERNEL);
+    if(Buffer == NULL) {
+        up(&Open_lock);
         return -ENOMEM;
     }
-    GV_bufr = GV_bufw = GV_buffer;
+    BufRP = BufWP = Buffer;
 
     /* Update links. I do it here 'cause I do not want memory copying (from the
     tty driver to the buffer) when there is no one to read. */
@@ -253,21 +253,21 @@ static ssize_t uif_read(struct file *filp, char *buf, size_t count,
     if(ppos != &filp->f_pos) { return -ESPIPE; }
 
     // Must sleep as long as there is no data.
-    if(down_interruptible(&GV_buf_lock)) { return -ERESTARTSYS; }
-    while(GV_bufr == GV_bufw) {
-        up(&GV_buf_lock);
+    if(down_interruptible(&Buffer_lock)) { return -ERESTARTSYS; }
+    while(BufRP == BufWP) {
+        up(&Buffer_lock);
         if(filp->f_flags & O_NONBLOCK) { return -EAGAIN; }
-        if(wait_event_interruptible(GV_inq, (GV_bufr != GV_bufw))) {
+        if(wait_event_interruptible(Inqueue, (BufRP != BufWP))) {
             return -ERESTARTSYS;
         }
-        if(down_interruptible(&GV_buf_lock)) { return -ERESTARTSYS; }
+        if(down_interruptible(&Buffer_lock)) { return -ERESTARTSYS; }
     }
 
     // Data is available, so give it to the user
     count = imin_uint(count, avail_R());
     mv_user(buf, count);
 
-    up(&GV_buf_lock);
+    up(&Buffer_lock);
     filp->f_dentry->d_inode->i_atime = CURRENT_TIME;
     return count;
 }
@@ -275,16 +275,16 @@ static ssize_t uif_read(struct file *filp, char *buf, size_t count,
 static loff_t uif_llseek(struct file *filp, loff_t offset, int origin) {
     /* Since you can not seek in the circular buffer, the only purpose of
     lseek() is to skip some bytes and "manually" advance the read pointer RP
-    (GV_bufr). Thus, the only accepted origin is SEEK_CUR (1). */
+    (BufRP). Thus, the only accepted origin is SEEK_CUR (1). */
 
     if(origin != 1) { return -ESPIPE; }
     if(offset == 0) { return 0; }
 
-    if(down_interruptible(&GV_buf_lock)) { return -ERESTARTSYS; }
-    GV_bufr += imin_uint(offset, avail_R());
-    if(GV_bufr > GV_buffer + GI_bufsize) { GV_bufr -= GI_bufsize; }
+    if(down_interruptible(&Buffer_lock)) { return -ERESTARTSYS; }
+    BufRP += imin_uint(offset, avail_R());
+    if(BufRP > Buffer + Bufsize) { BufRP -= Bufsize; }
 
-    up(&GV_buf_lock);
+    up(&Buffer_lock);
     return 0;
 }
 
@@ -294,7 +294,7 @@ static int uif_ioctl(struct inode *inode, struct file *filp, unsigned int cmd,
 
     switch(cmd) {
         case RPL_IOC_GETBUFSIZE:
-            return GI_bufsize;
+            return Bufsize;
         case RPL_IOC_GETRAVAIL:
             return avail_R();
         case RPL_IOC_GETWAVAIL:
@@ -306,7 +306,7 @@ static int uif_ioctl(struct inode *inode, struct file *filp, unsigned int cmd,
 }
 
 static unsigned int uif_poll(struct file *filp, poll_table *wait) {
-    poll_wait(filp, &GV_inq, wait);
+    poll_wait(filp, &Inqueue, wait);
     return POLLIN | POLLRDNORM;
 }
 
@@ -317,22 +317,22 @@ static int uif_close(struct inode *inode, struct file *filp) {
     rpl_qwrite = NULL;
     rpl_qioctl = NULL;
     rpl_qclose = NULL;
-    vfree(GV_buffer);
-    up(&GV_open_lock);
+    vfree(Buffer);
+    up(&Open_lock);
     return 0;
 }
 
 //-----------------------------------------------------------------------------
 inline static ssize_t avail_R(void) {
     // Return the number of available bytes to read
-    if(GV_bufw >= GV_bufr) { return GV_bufw - GV_bufr; }
-    return GV_bufw + GI_bufsize - GV_bufr;
+    if(BufWP >= BufRP) { return BufWP - BufRP; }
+    return BufWP + Bufsize - BufRP;
 }
 
 inline static ssize_t avail_W(void) {
     // Return the number of available bytes to write
-    if(GV_bufw >= GV_bufr) { return GV_bufr + GI_bufsize - GV_bufw - 1; }
-    return GV_bufr - GV_bufw - 1;
+    if(BufWP >= BufRP) { return BufRP + Bufsize - BufWP - 1; }
+    return BufRP - BufWP - 1;
 }
 
 inline static void get_tty_devnr(uint32_t *dev, struct tty_struct *tty) {
@@ -354,14 +354,14 @@ static int mv_buffer(struct rpld_packet *p, const char *buf, size_t count) {
     recognize the type. */
     static int GI_overrun = 0;
 
-    down_interruptible(&GV_buf_lock);
+    down_interruptible(&Buffer_lock);
 
     if(avail_W() < sizeof(struct rpld_packet) + count) {
         if(!GI_overrun) {
             printk(KERN_INFO PREFIX "mv_buffer(): Buffer overrun\n");
             ++GI_overrun;
         }
-        up(&GV_buf_lock);
+        up(&Buffer_lock);
         return -ENOSPC;
     } else {
         GI_overrun = 0;
@@ -370,8 +370,8 @@ static int mv_buffer(struct rpld_packet *p, const char *buf, size_t count) {
     mv_buffer2(p, sizeof(struct rpld_packet));
     if(count > 0) { mv_buffer2(buf, count); }
 
-    up(&GV_buf_lock);
-    wake_up(&GV_inq);
+    up(&Buffer_lock);
+    wake_up(&Inqueue);
     return count;
 }
 
@@ -380,15 +380,15 @@ inline static void mv_buffer2(const void *src, size_t count) {
     arbitrary data) into the circulary buffer. (Taking the wrappage into
     account!) The parent function -- mv_buffer() in this case -- must make sure
     there is enough room. */
+    size_t x = Buffer + Bufsize - BufWP;
 
-    size_t x = GV_buffer + GI_bufsize - GV_bufw;
     if(count <= x) {
-        memcpy(GV_bufw, src, count);
-        GV_bufw += count;
+        memcpy(BufWP, src, count);
+        BufWP += count;
     } else {
-        memcpy(GV_bufw, src, x);
-        memcpy(GV_buffer, src + x, count - x);
-        GV_bufw = GV_buffer + count - x;
+        memcpy(BufWP, src, x);
+        memcpy(Buffer, src + x, count - x);
+        BufWP = Buffer + count - x;
     }
     return;
 }
@@ -396,23 +396,23 @@ inline static void mv_buffer2(const void *src, size_t count) {
 inline static void mv_user(void *dest, size_t count) {
     /* mv_user() reads COUNT bytes from the circulary buffer and puts it into
     userspace memory. */
-    int x = GV_buffer + GI_bufsize - GV_bufr;
+    int x = Buffer + Bufsize - BufRP;
 
     /* Since this operation may block due to userspace page faults, the
     userspace daemon should really have DEST memory-locked. */
     if(count <= x) {
-        copy_to_user(dest, GV_bufr, count);
-        GV_bufr += count;
+        copy_to_user(dest, BufRP, count);
+        BufRP += count;
     } else {
-        copy_to_user(dest, GV_bufr, x);
-        copy_to_user(dest + x, GV_buffer, count - x);
-        GV_bufr = GV_buffer + count - x;
+        copy_to_user(dest, BufRP, x);
+        copy_to_user(dest + x, Buffer, count - x);
+        BufRP = Buffer + count - x;
     }
 
     return;
 }
 
-void my_swab(void *srcp, size_t count) {
+inline static void my_swab(void *srcp, size_t count) {
     if(count == 16) {
         uint16_t *ptr = srcp;
         *ptr = cpu_to_le16(*ptr);
