@@ -44,12 +44,14 @@ user/infod.c - INFO socket for RPLD
 static void *client_thread(void *);
 static void flush_table(void);
 static void set_status(uint32_t, int);
+static void getinfo_text(uint32_t, int);
 static void getinfo(uint32_t, int);
+static void zero_counters(void);
 
 static void block_signals(void);
+static void print_entry_text(int, struct tty *);
 static void print_entry(int, struct tty *);
 static int skprintf(int, const char *, ...);
-static char status_char(int);
 static int unix_server(const char *);
 
 // Variables
@@ -60,13 +62,13 @@ void infod_init(void) {
     /* bind() in unix_server() needs to be called as root (since in the default
     case we will create the socket in /var/run/), so init_infod() must come
     before setuid(). So it's an extra function. */
-    Svfd = unix_server(Opt.infod_port);
+    Svfd = unix_server(GOpt.infod_port);
 
     /* Limit the connections to the user owning the socket (and root). The
     Kernel code for AF_UNIX sockets only requires write permission on the
     socket for that. */
-    chown(Opt.infod_port, Opt.user_id, 0);
-    chmod(Opt.infod_port, S_IWUSR);
+    chown(GOpt.infod_port, GOpt.user_id, 0);
+    chmod(GOpt.infod_port, S_IWUSR);
     return;
 }
 
@@ -74,7 +76,7 @@ void *infod_main(void *arg) {
     // The INFOD mainloop which waits for incoming connections.
     block_signals();
 
-    while(Opt._running) {
+    while(1) {
         socklen_t sz = sizeof(struct sockaddr_un);
         struct sockaddr_un remote;
         pthread_t id;
@@ -94,6 +96,7 @@ static void *client_thread(void *arg) {
     int fd = (int)arg;
 
     while(1) {
+        static const uint32_t zero = 0;
         unsigned char req;
         uint32_t dev;
 
@@ -103,25 +106,38 @@ static void *client_thread(void *arg) {
         }
 
         PP_swab(&dev, sizeof(uint32_t));
-        if(req >= IFP_ACTIVATE && req <= IFP_DEACTIVSES) {
-            set_status(dev, req);
-        } else if(req == IFP_GETINFO) {
-            getinfo(dev, fd);
-        } else if(req == IFP_REMOVE) {
-            struct tty *tty;
 
-            pthread_mutex_lock(&Ttys_lock);
-            tty = get_tty(dev);
-            pthread_mutex_unlock(&Ttys_lock);
+        switch(req) {
+            case IFP_ACTIVATE ... IFP_DEACTIVSES:
+                set_status(dev, req);
+                break;
+            case IFP_GETINFO_T:
+                getinfo_text(dev, fd);
+                break;
+            case IFP_GETINFO:
+                getinfo(dev, fd);
+                break;
+            case IFP_REMOVE: {
+                struct tty *tty;
 
-            if(tty != NULL) { log_close(tty); }
-        } else if(req == IFP_FLUSH) {
-            flush_table();
-        } else {
-            notify(LOG_WARNING, NF_NEWLINE, "Unknown request %d\n", req);
+                pthread_mutex_lock(&Ttys_lock);
+                tty = get_tty(dev);
+                pthread_mutex_unlock(&Ttys_lock);
+
+                if(tty != NULL) { log_close(tty); }
+                break;
+            }
+            case IFP_FLUSH:
+                flush_table();
+                break;
+            case IFP_ZERO:
+                zero_counters();
+                break;
+            default:
+                notify(LOG_WARNING, NF_NEWLINE, "Unknown request %d\n", req);
+                break;
         }
 
-        static const uint32_t zero = 0;
         send_wait(fd, &zero, sizeof(uint32_t), 0);
     }
 
@@ -150,7 +166,7 @@ static void flush_table(void) {
     return;
 }
 
-static void getinfo(uint32_t dev, int fd) {
+static void getinfo_text(uint32_t dev, int fd) {
     if(dev == 0) {
         // No device given, send info about RPLD and all ttys
         struct HXbtree_node *nd;
@@ -160,7 +176,7 @@ static void getinfo(uint32_t dev, int fd) {
           "%2s %8s %-7s %9s %9s %4s %s\n"
           "==========================================================================\n"
           "  [---,---] *       %9llu %9llu    -\n"
-          "            opn/cls: %zu/%zu  r/w (pak): %zu/%zu  ioctl: %d  bad: %d\n"
+          "            opn/cls: %zu/%zu  r/w: %zu/%zu  ioctl: %zu  bad: %zu\n"
           "--------------------------------------------------------------------------\n",
           "AC", "DEVICE", "TTY", "BYTES IN", "OUT", "FD", "FILENAME",
           Stats.in, Stats.out, Stats.open, Stats.close, Stats.read, Stats.write,
@@ -171,7 +187,7 @@ static void getinfo(uint32_t dev, int fd) {
         travp = HXbtrav_init(Ttys, NULL);
 
         while((nd = HXbtraverse(travp)) != NULL) {
-            print_entry(fd, nd->data);
+            print_entry_text(fd, nd->data);
         }
 
         skprintf(fd, "--------------------------------------------------------------------------\n");
@@ -185,6 +201,41 @@ static void getinfo(uint32_t dev, int fd) {
         tty = get_tty(dev);
         pthread_mutex_unlock(&Ttys_lock);
 
+        if(tty == NULL) { return; }
+        print_entry_text(fd, tty);
+    }
+
+    return;
+}
+
+static void getinfo(uint32_t dev, int fd) {
+    if(dev == 0) {
+        // No device given, send info about RPLD and all ttys
+        struct HXbtree_node *nd;
+        struct HXbtrav *travp;
+
+        skprintf(fd, "%zu %zu %zu %zu %llu %llu %zu %zu\n",
+         Stats.open, Stats.close, Stats.read, Stats.write, Stats.in, Stats.out,
+         Stats.ioctl, Stats.badpack
+        );
+
+        pthread_mutex_lock(&Ttys_lock);
+        travp = HXbtrav_init(Ttys, NULL);
+
+        while((nd = HXbtraverse(travp)) != NULL) {
+            print_entry(fd, nd->data);
+        }
+
+        pthread_mutex_unlock(&Ttys_lock);
+        HXbtrav_free(travp);
+        return;
+    } else {
+        struct tty *tty;
+
+        pthread_mutex_lock(&Ttys_lock);
+        tty = get_tty(dev);
+        pthread_mutex_unlock(&Ttys_lock);
+
         if(tty == NULL) { return; }
         print_entry(fd, tty);
     }
@@ -206,6 +257,27 @@ static void set_status(uint32_t dev, int req) {
     return;
 }
 
+static void zero_counters(void) {
+    struct HXbtree_node *nd;
+    struct HXbtrav *travp;
+
+    pthread_mutex_lock(&Ttys_lock);
+    travp = HXbtrav_init(Ttys, NULL);
+
+    while((nd = HXbtraverse(travp)) != NULL) {
+        struct tty *tty = nd->data;
+        tty->in = tty->out = 0;
+    }
+
+    Stats.open = Stats.close = Stats.read = \
+    Stats.write = Stats.ioctl = Stats.badpack = 0;
+    Stats.in = Stats.out = 0;
+
+    pthread_mutex_unlock(&Ttys_lock);
+    HXbtrav_free(travp);
+    return;
+}
+
 //-----------------------------------------------------------------------------
 static void block_signals(void) {
     sigset_t set;
@@ -214,12 +286,42 @@ static void block_signals(void) {
     return;
 }
 
-static void print_entry(int fd, struct tty *tty) {
-    char buf[64];
+static void print_entry_text(int fd, struct tty *tty) {
+    char buf[64], status = ' ';
+
+    switch(tty->status) {
+        case IFP_ACTIVATE:
+            status = '*';
+            break;
+        case IFP_DEACTIVSES:
+            status = '.';
+            break;
+    }
+
     G_devname_nm(tty->dev, buf, sizeof(buf));
-    skprintf(fd, "%c [%3ld,%3ld] %-7s %9zu %9zu %4d %s\n",
-     status_char(tty->status), KD26_PARTS(tty->dev), buf, tty->in,
-     tty->out, tty->fd, tty->file);
+    skprintf(fd, "%c [%3ld,%3ld] %-7s %9zu %9zu %4d %s\n", status,
+     KD26_PARTS(tty->dev), buf, tty->in, tty->out, tty->fd, tty->file);
+    return;
+}
+
+static void print_entry(int fd, struct tty *tty) {
+    char buf[64], status = 'x';
+
+    switch(tty->status) {
+        case IFP_ACTIVATE:
+            status = 'A';
+            break;
+        case IFP_DEACTIVATE:
+            status = 'D';
+            break;
+        case IFP_DEACTIVSES:
+            status = 'S';
+            break;
+    }
+
+    G_devname_nm(tty->dev, buf, sizeof(buf));
+    skprintf(fd, "%c %ld %ld %s %zu %zu %d %s\n", status, KD26_PARTS(tty->dev),
+     buf, tty->in, tty->out, tty->fd, tty->file);
     return;
 }
 
@@ -238,18 +340,6 @@ static int skprintf(int fd, const char *fmt, ...) {
     return s;
 }
 
-static char status_char(int s) {
-    switch(s) {
-        case IFP_ACTIVATE:
-            return '*';
-        case IFP_DEACTIVATE:
-            return ' ';
-        case IFP_DEACTIVSES:
-            return '.';
-    }
-    return ' ';
-}
-
 static int unix_server(const char *port) {
     struct sockaddr_un sk;
     int fd = -1;
