@@ -39,20 +39,11 @@ user/rdsh.c - Shared functions for RPLD/INFOD/RPLINFO
 pthread_mutex_t Ttys_lock = PTHREAD_MUTEX_INITIALIZER;
 struct HXbtree *Ttys = NULL;
 struct Statmap_t Stats;
-struct Optmap_t Opt = {
-    ._running   = 1,
-    .bsize      = 16384,
-    .ovdev      = NULL,
-    .fbdev      = "/dev/rpl:/dev/misc/rpl",
-    .nocreat    = 0,
-    .ofmt       = "%u@%d.%t.%l",
+struct GOptmap_t GOpt = {
+    .user_id    = -1,
     .syslog     = 0,
     .verbose    = 0,
-    .user_id    = -1,
-
-    // infod.c
-    .infod_port  = "/var/run/.rplinfod_socket",
-    .infod_start = 0,
+    .infod_port = "/var/run/.rplinfod_socket",
 };
 
 // LG vars
@@ -156,6 +147,7 @@ struct tty *get_tty(uint32_t dev) {
     if((tty = malloc(sizeof(struct tty))) == NULL) { return NULL; }
 
     tty->dev    = dev;
+    tty->uid    = -1;
     tty->fd     = -1;
     tty->status = IFP_ACTIVATE;
     tty->in     = tty->out = 0;
@@ -173,6 +165,8 @@ struct tty *get_tty(uint32_t dev) {
 void log_close(struct tty *tty) {
     /* Close the logfile and release the tty struct if it does not have special
     options are set. */
+    pthread_mutex_lock(&Ttys_lock);
+
     close(tty->fd);
     tty->fd = -1;
     if(tty->file != NULL) {
@@ -180,7 +174,6 @@ void log_close(struct tty *tty) {
         tty->file = NULL; // infod
     }
 
-    pthread_mutex_lock(&Ttys_lock);
     if(tty->status != IFP_DEACTIVATE) {
         /* If the status is IFP_ACTIVATED, it is reinstantiated upon next
         get_tty(). If it is IFP_DEACTIVSES, it will change to IFP_ACTIVATED,
@@ -193,7 +186,7 @@ void log_close(struct tty *tty) {
 }
 
 int notify(int lv, unsigned int opts, const char *fmt, ...) {
-    if(Opt.verbose) {
+    if(GOpt.verbose) {
         int rv;
         va_list argp;
         va_start(argp, fmt);
@@ -202,7 +195,7 @@ int notify(int lv, unsigned int opts, const char *fmt, ...) {
         va_end(argp);
         return rv;
     }
-    if(Opt.syslog) {
+    if(GOpt.syslog) {
         va_list argp;
         va_start(argp, fmt);
         vsyslog(lv, fmt, argp);
