@@ -60,14 +60,13 @@ enum { // skip types
 struct {
     double factor;
     int follow, nodelay, seek_type;
-    long ovcorr, maxdelay;
-    long seek_cval;
+    long ovcorr, maxdelay, seek_cval;
 } Opt = {
-    .factor    = 1.0,
-    .follow    = 0,
-    .maxdelay  = -1,
-    .nodelay   = 0,
-    .seek_type = SKIP_NONE,
+    .factor    = 1.0,       // -S
+    .follow    = 0,         // -F/-f
+    .maxdelay  = -1,        // -m
+    .nodelay   = 0,         // -T
+    .seek_type = SKIP_NONE, // -J/-j
     .seek_cval = 0,
 };
 
@@ -123,9 +122,7 @@ static void replay_file(int fd) {
     long skew = 0;
     int tick = 0;
 
-    if(Opt.follow == FM_LIVE && !seek_to_end(fd)) {
-        return;
-    }
+    if(Opt.follow == FM_LIVE && !seek_to_end(fd)) { return; }
 
     while((eax = read_waitfm(fd, &packet, sizeof(struct disk_packet))) ==
      sizeof(struct disk_packet)) {
@@ -155,6 +152,7 @@ static void replay_file(int fd) {
                     // No delay after the first packet has been read...
                     ++tick;
                     if(Opt.seek_cval > 0) {
+                        // Urgh, these two lines are replicated below so much
                         memcpy(&stamp, &packet.tv, sizeof(struct timeval));
                         read_nullfm(fd, packet.size);
                         break;
@@ -180,8 +178,8 @@ static void replay_file(int fd) {
                     }
                     if(Opt.maxdelay > 0 &&
                      (x = tv2usec(&delta)) > Opt.maxdelay) {
-                        /* -m switch for those who do not want to wait that
-                        long. */
+                        /* -m switch for those who do not want to wait their
+                        lifetime. */
                         usec2tv(Opt.maxdelay, &delta);
                     }
                     usleep_ovcorr(&delta, &skew);
@@ -204,7 +202,7 @@ static void replay_file(int fd) {
     }
 
     if(eax < 0) {
-        perror("\n" "<Error while reading from stream>\n" "read() returned:");
+        perror("\n" "<Error while reading from stream>\n" "read():");
     }
 
     printf("\n" "<Log replaying finished>\n");
@@ -234,6 +232,8 @@ static unsigned long calc_ovcorr(unsigned long ad, int rd) {
 }
 
 static int find_next_packet(int fd) {
+    /* There is more algorithmic code than simple code in ttyreplay.
+    Outstanding. */
 #define LZ           sizeof(struct disk_packet)
 #define BZ           (2 * LZ)
 #define MAGIC_OFFSET offsetof(struct disk_packet, magic)
@@ -397,7 +397,7 @@ static int get_options(int *argc, const char ***argv) {
                 break;
             case 'j':
                 Opt.seek_type = SKIP_WRPACKET;
-                Opt.seek_cval = strtoll(tmp, NULL, 0);
+                Opt.seek_cval = strtol(tmp, NULL, 0);
                 free(tmp);
                 break;
             case 'm':
@@ -425,9 +425,7 @@ static int get_options(int *argc, const char ***argv) {
 }
 
 static ssize_t read_through(int in, int out, size_t count) {
-    /* Read from IN and directly give it to OUT. This is like sendfile(),
-    but does not use it, since it gives EINVAL most of the times, probably
-    because "out" is a tty and does not seem to support sendpage. */
+    // Read from IN and directly give it to OUT. This is like sendfile().
     char buf[BUFSIZE];
     size_t rem = count;
 
@@ -476,7 +474,9 @@ static ssize_t read_waitfm(int fd, void *buf, size_t count) {
 
 static int seek_to_end(int fd) {
     if(lseek(fd, 0, SEEK_END) == -1 && errno == ESPIPE) {
-        // Some workaround for non-seekable descriptors
+        /* Some workaround for non-seekable descriptors. G_skip() is not
+        suitable, since ... it's just not designed to do what is below, i.e.
+        non-blocking-until-EOF-call-it-something. */
         char buf[BUFSIZE];
         fcntl(fd, F_SETFL, fcntl(fd, F_GETFL) | O_NONBLOCK);
 
