@@ -52,10 +52,11 @@ extern int posix_memalign(void **, size_t, size_t);
 // The prototype order is the same as the function body order
 static void mainloop(int);
 
-static int packet_preaction(struct mem_packet *);
-static int packet_action(struct mem_packet *, struct tty *, int);
-static int packet_postaction(struct mem_packet *, struct tty *);
+static int packet_action1(struct mem_packet *);
+static int packet_action2(struct mem_packet *, struct tty *);
+static int packet_action3(struct mem_packet *, struct tty *, int);
 
+static void log_cuid(struct tty *);
 static int log_open(struct tty *);
 static void log_write(struct mem_packet *, struct tty *, int);
 
@@ -76,11 +77,25 @@ static int pconfig_user(const char *, unsigned char, void *, void *);
 inline static const char *basename(const char *);
 static char *getnamefromuid(uid_t, char *, size_t);
 static uid_t getuidfromname(const char *);
-static char *replace(char *, const char *, size_t, char **);
-inline static int value_cmp(void *, void *);
+static int value_cmp(void *, void *);
 
 // Global variables (begin with uppercase character)
 static void *Buffer = NULL;
+static struct {
+    int _running, nocreat;
+    char *ovdev, *fbdev, *ofmt;
+    long bsize;
+
+    int infod_start;
+} Opt = {
+    ._running    = 1,
+    .bsize       = 16384,
+    .ovdev       = NULL,          // -D
+    .fbdev       = "/dev/rpl:/dev/misc/rpl",
+    .nocreat     = 0,             // -Q
+    .ofmt        = "%u@%d.%t.%l", // -O
+    .infod_start = 0,             // -I
+};
 
 //-----------------------------------------------------------------------------
 int main(int argc, const char **argv) {
@@ -100,7 +115,7 @@ int main(int argc, const char **argv) {
     if(!get_options(&argc, &argv)) { return EXIT_FAILURE; }
     memset(&Stats, 0, sizeof(Stats));
 
-    if(Opt.verbose) {
+    if(GOpt.verbose) {
         printf(
           "# rpld " TTYRPLD_VERSION "\n"
           "This program comes with ABSOLUTELY NO WARRANTY; it is free"
@@ -111,7 +126,7 @@ int main(int argc, const char **argv) {
         );
     }
 
-    if((Ttys = HXbtree_init(HXBT_ASSOC | HXBT_LKEY | HXBT_FCMP | HXBT_XCPY,
+    if((Ttys = HXbtree_init(HXBT_ASSOC | HXBT_LKEY | HXBT_XCPY | HXBT_FCMP,
      value_cmp)) == NULL) {
         perror("HXbtree_init()");
         return EXIT_FAILURE;
@@ -126,21 +141,21 @@ int main(int argc, const char **argv) {
     init_sighandler();
 
     // Callback tick for statistics
-    if(Opt.verbose) { alarm(1); }
+    if(GOpt.verbose) { alarm(1); }
 
     if(Opt.infod_start) { infod_init(); }
 
-    if(Opt.syslog) { openlog("rpld", LOG_PID, LOG_DAEMON); }
+    if(GOpt.syslog) { openlog("rpld", LOG_PID, LOG_DAEMON); }
 
     // Not seteuid(), because it shall not be posibble to regain privs.
-    if(Opt.user_id >= 0) { setuid(Opt.user_id); }
+    if(GOpt.user_id >= 0) { setuid(GOpt.user_id); }
 
     if(Opt.infod_start) { pthread_create(&infod_id, NULL, infod_main, NULL); }
 
     mainloop(fd);
 
     if(Opt.infod_start) {
-        unlink(Opt.infod_port);
+        unlink(GOpt.infod_port);
         pthread_cancel(infod_id);
         pthread_join(infod_id, NULL);
     }
@@ -151,21 +166,11 @@ int main(int argc, const char **argv) {
 }
 
 static void mainloop(int fd) {
-    ssize_t (*reader)(int, void *, size_t) = read;
-
-    { /* read() on the device might return less than we request, so we use
-      read_wait() and loop until there is data. However, we do not want to wait
-      on e.g. pipes. */
-      struct stat sb;
-      fstat(fd, &sb);
-      if(S_ISCHR(sb.st_mode)) { reader = read_wait; }
-    }
-
     while(Opt._running) {
         struct mem_packet packet;
         struct tty *tty;
 
-        if(reader(fd, &packet, sizeof(struct rpld_packet)) <
+        if(read(fd, &packet, sizeof(struct rpld_packet)) <
          sizeof(struct rpld_packet)) {
             Opt._running = 0;
             break;
@@ -191,7 +196,7 @@ static void mainloop(int fd) {
         the amount of data which has to be copied over the device. */
         gettimeofday(&packet.tv, NULL);
 
-        if(!packet_preaction(&packet)) {
+        if(!packet_action1(&packet)) {
             G_skip(fd, packet.size, 0);
             continue;
         }
@@ -200,19 +205,19 @@ static void mainloop(int fd) {
         tty = get_tty(packet.dev);
         pthread_mutex_unlock(&Ttys_lock);
 
-        if(tty == NULL || !packet_postaction(&packet, tty)) {
+        if(tty == NULL || !packet_action2(&packet, tty)) {
             G_skip(fd, packet.size, 0);
             continue;
         }
 
-        packet_action(&packet, tty, fd);
+        packet_action3(&packet, tty, fd);
     }
 
     return;
 }
 
 //-----------------------------------------------------------------------------
-static int packet_preaction(struct mem_packet *packet) {
+static int packet_action1(struct mem_packet *packet) {
     /* pty masters are an exact copy of their slaves,
     so no need to record them too. */
     register long maj = K26_MAJOR(packet->dev);
@@ -266,22 +271,7 @@ static int packet_preaction(struct mem_packet *packet) {
     return 1;
 }
 
-static int packet_action(struct mem_packet *packet, struct tty *tty, int fd) {
-    switch(packet->event) {
-       /* EV_OPEN is not handled since a logfile will automatically be opened
-       in log_write() if necessary. */
-       case EV_READ:
-       case EV_WRITE:
-           log_write(packet, tty, fd);
-           break;
-       case EV_CLOSE:
-           log_close(tty);
-           break;
-    }
-    return 1;
-}
-
-static int packet_postaction(struct mem_packet *packet, struct tty *tty) {
+static int packet_action2(struct mem_packet *packet, struct tty *tty) {
     /* The name is wrong when you look at the caller, since postaction()
     actually comes before packet_action(). Anyway, it's post the get_tty(). */
     if(tty->status != IFP_ACTIVATE) {
@@ -298,24 +288,53 @@ static int packet_postaction(struct mem_packet *packet, struct tty *tty) {
     return 1;
 }
 
+static int packet_action3(struct mem_packet *packet, struct tty *tty, int fd) {
+    switch(packet->event) {
+        case EV_OPEN:
+            /* EV_OPEN is not handled since a logfile will automatically be opened
+            in log_write() if necessary. */
+            log_cuid(tty);
+            break;
+        case EV_READ:
+        case EV_WRITE:
+            log_write(packet, tty, fd);
+            break;
+        case EV_CLOSE:
+            log_close(tty);
+            break;
+    }
+    return 1;
+}
+
 //-----------------------------------------------------------------------------
+static void log_cuid(struct tty *tty) {
+    struct stat sb;
+    char buf[32];
+
+    if(tty->uid == -1) { return; }
+    G_devname_fs(tty->dev, buf, sizeof(buf));
+    if(stat(buf, &sb) == 0 && sb.st_uid != tty->uid) {
+        tty->in = tty->out = 0;
+        log_open(tty);
+    }
+    return;
+}
+
 static int log_open(struct tty *tty) {
-    char buf[MAXFNLEN], devnode[64], fmday[16], fmtime[16], user[32];
-    char *subst_catalog[] = {
-        "d", fmday,
-        "l", devnode,
-        "t", fmtime,
-        "u", user,
-        NULL
-    };
+    char buf[MAXFNLEN], devnode[32], fmday[16], fmtime[16], user[32];
+    struct HX_repmap catalog[] = {{'d', NULL, fmday}, {'l', NULL, devnode},
+     {'t', NULL, fmtime}, {'u', NULL, user}, {0}};
 
     { // User
       struct stat sb;
-      G_devname_fs(tty->dev, devnode, 64);
+      G_devname_fs(tty->dev, devnode, sizeof(devnode));
       if(stat(devnode, &sb) != 0) {
           strcpy(user, "NONE");
-      } else if(getnamefromuid(sb.st_uid, user, 32) == NULL) {
-          snprintf(user, 32, "%d", sb.st_uid);
+      } else {
+          tty->uid = sb.st_uid;
+          if(getnamefromuid(sb.st_uid, user, sizeof(user)) == NULL) {
+              snprintf(user, sizeof(user), "%d", sb.st_uid);
+          }
       }
     }
 
@@ -323,16 +342,16 @@ static int log_open(struct tty *tty) {
       time_t now = time(NULL);
       struct tm now_tm;
       localtime_r(&now, &now_tm);
-      strftime(fmday,  16, "%Y%m%d", &now_tm);
-      strftime(fmtime, 16, "%H%M%S", &now_tm);
+      strftime(fmday,  sizeof(fmday),  "%Y%m%d", &now_tm);
+      strftime(fmtime, sizeof(fmtime), "%H%M%S", &now_tm);
     }
 
     // Simple tty name
-    G_devname_nm(tty->dev, devnode, 64);
-    replace(buf, Opt.ofmt, MAXFNLEN, subst_catalog);
+    G_devname_nm(tty->dev, devnode, sizeof(devnode));
+    HX_strrep(buf, MAXFNLEN, Opt.ofmt, catalog);
 
     // Open log
-    tty->file = HX_strdup(basename(buf));
+    HX_strclone(&tty->file, basename(buf));
     if(Opt.nocreat) { snprintf(buf, MAXFNLEN, "/dev/null"); }
     if((tty->fd = open(buf, O_WRONLY | O_CREAT | O_APPEND, 0600)) < 0) {
         notify(LOG_ERR, NF_NEWLINE, "Could not open %s: %s\n",
@@ -390,7 +409,7 @@ static int init_device(const char *in_devs) {
         if((fd = open(new_dev, O_RDONLY)) == -1) {
             new_dev = NULL;
             perror("Could not connect to RPL device");
-        } else if(Opt.verbose) {
+        } else if(GOpt.verbose) {
             printf("Connected to RPL device\n");
         }
         unlink(new_dev);
@@ -403,7 +422,7 @@ static int init_device(const char *in_devs) {
 
         while((devp = HX_strsep(&devs, ":")) != NULL) {
             if((fd = open(devp, O_RDONLY)) >= 0) {
-                if(Opt.verbose) { printf("Connected to %s\n", devp); }
+                if(GOpt.verbose) { printf("Connected to %s\n", devp); }
                 break;
             }
             if(errno != ENOENT) {
@@ -444,16 +463,16 @@ static void deinit_sbuffer(void) {
 }
 
 static const char *mknod_rpldev(void) {
-    FILE *fp = fopen("/proc/misc", "r");
     int32_t minor = -1;
-    char buf[80];
+    char buf[128];
+    FILE *fp;
 
-    if(fp == NULL) {
+    if((fp = fopen("/proc/misc", "r")) == NULL) {
         perror("Could not open /proc/misc");
         return NULL;
     }
 
-    while(fgets(buf, 80, fp) != NULL) {
+    while(fgets(buf, sizeof(buf), fp) != NULL) {
         char *ptr = buf, *name;
         while(!isdigit(*ptr)) { ++ptr; }
         minor = strtol(ptr, NULL, 0);
@@ -478,7 +497,7 @@ static const char *mknod_rpldev(void) {
         return NULL;
     }
 
-    chown(NODEPATH, Opt.user_id, 0);
+    chown(NODEPATH, GOpt.user_id, 0);
     return NODEPATH;
 }
 
@@ -508,13 +527,13 @@ static int init_sighandler(void) {
 
 static void sighandler_int(int s) {
     if(Opt._running-- == 0) {
-        if(Opt.verbose) {
+        if(GOpt.verbose) {
             printf("Second time we received SIGINT/SIGTERM,"
              " exiting immediately.\n");
         }
         exit(EXIT_FAILURE);
     }
-    if(Opt.verbose) {
+    if(GOpt.verbose) {
         printf("\n" "Received SIGINT/SIGTERM, shutting down.\n");
     } else {
         // If this is not done, process hangs until some fs activity
@@ -530,7 +549,7 @@ static void sighandler_alrm(int s) {
       Stats.open, Stats.close, Stats.read, Stats.write, Stats.in,
       Stats.out, Stats.ioctl, Stats.badpack
     );
-    if(Opt.verbose) { alarm(1); }
+    if(GOpt.verbose) { alarm(1); }
     return;
 }
 
@@ -547,7 +566,7 @@ static int get_options(int *argc, const char ***argv) {
         {NULL, 'D', POPT_ARG_STRING, &Opt.ovdev, 0,
          "Path to the RPL device", "file"},
         {NULL, 'I', POPT_ARG_NONE, &Opt.infod_start, 0,
-         "Start infod subcomponent", NULL},
+         "Start INFOD subcomponent", NULL},
         {NULL, 'O', POPT_ARG_STRING, &Opt.ofmt, 0,
          "Override OFMT variable", "string"},
         {NULL, 'Q', POPT_ARG_NONE, &Opt.nocreat, 0,
@@ -556,9 +575,9 @@ static int get_options(int *argc, const char ***argv) {
          "User to change to", "user"},
         {NULL, 'c', POPT_ARG_STRING, &tmp, 'c',
          "Read configuration from file (on top of hardcoded conf)", "file"},
-        {NULL, 's', POPT_ARG_NONE, &Opt.syslog, 0,
+        {NULL, 's', POPT_ARG_NONE, &GOpt.syslog, 0,
          "Print warnings/errors to syslog", NULL},
-        {NULL, 'v', POPT_ARG_NONE, &Opt.verbose, 0,
+        {NULL, 'v', POPT_ARG_NONE, &GOpt.verbose, 0,
          "Print statistics while rpld is running", NULL},
         POPT_AUTOHELP
         POPT_TABLEEND
@@ -602,12 +621,12 @@ static int get_options(int *argc, const char ***argv) {
 
 static int read_config(const char *file) {
     static struct rconfig_opt options_table[] = {
-        {"OVDEVICE", RCONF_STRING, &Opt.ovdev,  NULL},
-        {"FBDEVICE", RCONF_STRING, &Opt.fbdev,  NULL},
-        {"OFMT",     RCONF_STRING, &Opt.ofmt,   NULL},
-        {"USER",     RCONF_CB,     NULL,        pconfig_user},
+        {"OVDEVICE", RCONF_STRING, &Opt.ovdev, NULL},
+        {"FBDEVICE", RCONF_STRING, &Opt.fbdev, NULL},
+        {"OFMT",     RCONF_STRING, &Opt.ofmt,  NULL},
+        {"USER",     RCONF_CB,     NULL,       pconfig_user},
 
-        {"INFOD_PORT", RCONF_STRING, &Opt.infod_port, NULL},
+        {"INFOD_PORT", RCONF_STRING, &GOpt.infod_port, NULL},
         {"START_INFOD", RCONF_IBOOL, &Opt.infod_start, NULL},
         {NULL},
     };
@@ -629,7 +648,7 @@ static int read_config_bp(const char *app_path, const char *file) {
 
 static int pconfig_user(const char *key, unsigned char type, void *ptr,
  void *uptr) {
-    if((Opt.user_id = getuidfromname(ptr)) < 0) {
+    if((GOpt.user_id = getuidfromname(ptr)) < 0) {
         fprintf(stderr, "No such user: %s\n", (const char *)ptr);
         exit(EXIT_FAILURE);
     }
@@ -638,6 +657,7 @@ static int pconfig_user(const char *key, unsigned char type, void *ptr,
 
 //-----------------------------------------------------------------------------
 inline static const char *basename(const char *s) {
+    // Return file component of a full-path filename
     const char *p = strrchr(s, '/');
     if(p != NULL) { return p + 1; }
     return s;
@@ -646,7 +666,7 @@ inline static const char *basename(const char *s) {
 static char *getnamefromuid(uid_t uid, char *result, size_t len) {
     struct passwd ent, *ep;
     char additional[1024];
-    getpwuid_r(uid, &ent, additional, 1024, &ep);
+    getpwuid_r(uid, &ent, additional, sizeof(additional), &ep);
     if(ep == NULL) { return NULL; }
     strncpy(result, ep->pw_name, len - 1);
     result[len - 1] = '\0';
@@ -656,59 +676,12 @@ static char *getnamefromuid(uid_t uid, char *result, size_t len) {
 static uid_t getuidfromname(const char *name) {
     struct passwd ent, *ep;
     char additional[1024];
-    getpwnam_r(name, &ent, additional, 1024, &ep);
+    getpwnam_r(name, &ent, additional, sizeof(additional), &ep);
     if(ep == NULL) { return -1; }
     return ep->pw_uid;
 }
 
-static char *replace(char *dest, const char *src, size_t count,
- char **catalog) {
-    char *destp = dest;
-    *destp = '\0';
-    destp[count - 1] = '\0';
-
-    while(*src != '\0' && count > 1) {
-        size_t max = min_uint(strcspn(src, "%"), count - 1);
-        char **catp = catalog, *key, *value;
-        int got_spec = 0;
-
-        strncpy(destp, src, max);
-        src   += max;
-        destp += max;
-        count -= max;
-        if(*src != '%' || count < 2) { break; }
-        if(*++src == '%') { // "%%"
-            *destp++ = '%';
-            if(--count < 2) { break; }
-            ++src;
-            continue;
-        }
-        if((unsigned char)*src >= 128 || !isalpha(*src)) {
-            notify(LOG_WARNING, NF_NEWLINE, "%% without specifier in OFMT.\n");
-            break;
-        }
-
-        while((key = *catp++) != NULL) {
-            value = *catp++;
-            if(*src == *key) {
-                strncpy(destp, value, count - 1);
-                max = strlen(destp);
-                destp += max;
-                count -= max;
-                ++got_spec;
-                break;
-            }
-        }
-        if(count < 2) { break; }
-        if(!got_spec) {
-            notify(LOG_WARNING, NF_NEWLINE, "Invalid specifier: %%%c\n", *src);
-        }
-        ++src;
-    }
-    return dest;
-}
-
-inline static int value_cmp(void *pa, void *pb) {
+static int value_cmp(void *pa, void *pb) {
     return (pa > pb) - (pa < pb);
 }
 
